QudsCheckboxListTile constructor
const
QudsCheckboxListTile({
- Key? key,
- required bool value,
- ListTileControlAffinity controlAffinity = ListTileControlAffinity.leading,
- Widget? title,
- Widget? secondary,
- Color? checkColor,
- Color? unCkeckColor,
- dynamic onChanged(
- bool newValue
- String? tooltip,
- TextDirection? textDirection,
- bool isThreeLine = false,
- double? size,
value the check state of this checkbox
checkColor the color of the widget when its value set to true
unCheckColor the color of the widget when its value set to false
onChanged called when the check state is changed.
tooltip a short message shown when the user hold a tap over the checkbox
size the size of the ckeck icon.
Implementation
const QudsCheckboxListTile(
{Key? key,
required this.value,
this.controlAffinity = ListTileControlAffinity.leading,
this.title,
this.secondary,
this.checkColor,
this.unCkeckColor,
this.onChanged,
this.tooltip,
this.textDirection,
this.isThreeLine = false,
this.size})
: super(key: key);